Cargo

Struct Cargo 

pub struct Cargo { /* private fields */ }

Implementations

Source

impl Cargo

Auto-generated by derive_getters::Getters.

pub fn config(&self) -> &Config

Get field config from instance of Cargo.

pub fn version(&self) -> &Version

Get field version from instance of Cargo.

pub fn logger(&self) -> &Logger

Get field logger from instance of Cargo.

pub fn env(&self) -> &HashMap<String, String>

Get field env from instance of Cargo.

pub fn updated(&self) -> &bool

Get field updated from instance of Cargo.

pub fn dry_run(&self) -> &bool

Get field dry_run from instance of Cargo.

Source

impl Cargo

pub fn init( config: Config, version: Version, level: LogLevel, env: HashMap<String, String>, updated: bool, dry_run: bool, ) -> Result<Self, Alert>

Initialize the plugin with the data from the cli arguments.

pub fn install(&self) -> Result<(), Alert>

Install cargo-edit to use for bumping the version in Cargo.toml.

pub fn set_version(&self) -> Result<(), Alert>

Run cargo set-version to bump the version in Cargo.toml.

pub fn publish(&self, dry_run: bool) -> Result<(), Alert>

Run cargo publish to publish the crate to crates.io. Can do a dry run for testing.

pub fn release(&self) -> Result<(), Alert>

Run the full release process for cargo.