pub struct Config { /* private fields */ }Implementations
Sourceimpl Config
Auto-generated by derive_getters::Getters.
impl Config
Auto-generated by derive_getters::Getters.
Sourcepub fn set_version(&self) -> &bool
pub fn set_version(&self) -> &bool
A flag specifying whether to set the version in the Cargo.toml file.
Sourcepub fn act_on_no_update(&self) -> &bool
pub fn act_on_no_update(&self) -> &bool
A flag specifying whether to run this plugin even if the version was no updated.