pub struct Cargo { /* private fields */ }Implementations
Sourceimpl Cargo
impl Cargo
Sourcepub fn init(
config: Config,
version: Version,
level: LogLevel,
env: HashMap<String, String>,
updated: bool,
dry_run: bool,
) -> Result<Self, Alert>
pub fn init( config: Config, version: Version, level: LogLevel, env: HashMap<String, String>, updated: bool, dry_run: bool, ) -> Result<Self, Alert>
Initialize the plugin with the data from the cli arguments.
Sourcepub fn install(&self) -> Result<(), Alert>
pub fn install(&self) -> Result<(), Alert>
Install cargo-edit to use for bumping the version in Cargo.toml.
Sourcepub fn set_version(&self) -> Result<(), Alert>
pub fn set_version(&self) -> Result<(), Alert>
Run cargo set-version to bump the version in Cargo.toml.